@@ -17,6 +17,7 @@ from beartype.typing import (
     Callable,
     Dict,
     Iterable,
+    Mapping,
     Optional,
     Tuple,
     Type,
@@ -24,10 +25,12 @@ from beartype.typing import (
     Union,
 )
 from beartype._cave._cavefast import (
+    # MethodBoundInstanceOrClassType,
     MethodDecoratorClassType,
     MethodDecoratorPropertyType,
     MethodDecoratorStaticType,
 )
+from beartype._data.hint.pep.sign.datapepsigncls import HintSign
 from types import (
     CodeType,
     FrameType,
@@ -67,6 +70,12 @@ BeartypeableT = TypeVar(
         # A C-based unbound static method descriptor (i.e., a pure-Python
         # unbound function decorated by the builtin @staticmethod decorator).
         MethodDecoratorStaticType,
+
+        #FIXME: Currently unused, but preserved for posterity.
+        # # A C-based bound method descriptor (i.e., a pure-Python unbound
+        # # function bound to an object instance on Python's instantiation of that
+        # # object) *OR*...
+        # MethodBoundInstanceOrClassType,
     ],
 )
 '''
@@ -164,6 +173,22 @@ func_wrapper_scope, hint_forwardrefs_class_basename)``, where:
   List['YoClass']]``).
 '''
 
+# ....................{ HINTS ~ dict                       }....................
+MappingKeysStr = Mapping[str, object]
+'''
+PEP-compliant type hint matching a mapping whose keys are *all* strings.
+'''
+
+
+HintSignTrie = Dict[str, Union[HintSign, 'HintSignTrie']]
+'''
+PEP-compliant type hint matching a **sign trie** (i.e.,
+dictionary-of-dictionaries tree data structure enabling efficient mapping from
+the machine-readable representations of type hints created by an arbitrary
+number of type hint factories defined by an external third-party package to
+their identifying sign).
+'''
+
 # ....................{ HINTS ~ iterable                   }....................
 IterableStrs = Iterable[str]
 '''
