@@ -13,18 +13,6 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ TODO                               }....................
-#FIXME: *YIKES.* Tragically, the existing ViolationCause.find_cause() method
-#completely fails to suffice to define the "culprit" parameter for the
-#"BeartypeCallHintViolation" exception. We'll need to fundamentally refactor
-#*ALL* of this as follows:
-#* In the get_beartype_violation() function:
-#  * Set the "culprit" parameter for the "BeartypeCallHintViolation" exception
-#    as follows:
-#        cause = ViolationCause(...).find_cause()
-#        culprit = cause.pith  # <-- pretty sure that's right... pretty. sure.
-#
-#Extremely non-trivial, but extremely necessary. Let's do this, everybody.
-
 #FIXME: The recursive "ViolationCause" class strongly overlaps with the equally
 #recursive (and substantially superior) "beartype.door.TypeHint" class. Ideally:
 #* Define a new private "beartype.door._doorerror" submodule.
@@ -73,7 +61,7 @@ from beartype._util.hint.pep.utilpeptest import (
     is_hint_pep,
     is_hint_pep_args,
 )
-from beartype._check.conv.convsanify import sanify_hint_child
+from beartype._check.conv.convsanify import sanify_hint_any
 from beartype._util.hint.utilhinttest import is_hint_ignorable
 
 # ....................{ CLASSES                            }....................
@@ -115,10 +103,18 @@ class ViolationCause(object):
         * If this hint is PEP-compliant, the possibly empty tuple of all
           arguments subscripting (indexing) this hint.
 
-        * Else, ``None``.
+        * Else, :data:`None`.
     pith : Any
         Arbitrary object to be validated.
-    random_int: Optional[int]
+    pith_name : Optional[str]
+        Either:
+
+        * If this hint directly annotates a callable parameter (as the root type
+          hint of that parameter), the name of this parameter.
+        * If this hint directly annotates a callable return (as the root type
+          hint of that return), the magic string ``"return"``.
+        * Else, :data:`None`.
+    random_int : Optional[int]
         **Pseudo-random integer** (i.e., unsigned 32-bit integer
         pseudo-randomly generated by the parent :func:`beartype.beartype`
         wrapper function in type-checking randomly indexed container items by
@@ -147,6 +143,7 @@ class ViolationCause(object):
         'hint_sign',
         'hint_childs',
         'pith',
+        'pith_name',
         'random_int',
         '_hint',
     )
@@ -160,6 +157,7 @@ class ViolationCause(object):
         'func',
         'hint',
         'pith',
+        'pith_name',
         'random_int',
     ))
     '''
@@ -179,6 +177,7 @@ class ViolationCause(object):
         func: Callable,
         conf: BeartypeConf,
         pith: Any,
+        pith_name: Optional[str],
         hint: Any,
         cause_indent: str,
         exception_prefix: str,
@@ -189,10 +188,16 @@ class ViolationCause(object):
     ) -> None:
         '''
         Initialize this object.
+
+        Parameters
+        ----------
+        See the class docstring for a description of these parameters.
         '''
         assert callable(func), f'{repr(func)} not callable.'
         assert isinstance(conf, BeartypeConf), (
             f'{repr(conf)} not configuration.')
+        assert isinstance(pith_name, NoneTypeOr[str]), (
+            f'{repr(pith_name)} not string or "None".')
         assert isinstance(cause_indent, str), (
             f'{repr(cause_indent)} not string.')
         assert isinstance(exception_prefix, str), (
@@ -206,6 +211,7 @@ class ViolationCause(object):
         self.func = func
         self.conf = conf
         self.pith = pith
+        self.pith_name = pith_name
         self.cause_indent = cause_indent
         self.exception_prefix = exception_prefix
         self.random_int = random_int
@@ -216,6 +222,9 @@ class ViolationCause(object):
         self.hint_childs: Tuple = None  # type: ignore[assignment]
 
         # Classify this hint *AFTER* initializing all parameters above.
+        #
+        # Note that this assignment magically calls the "hint" property setter
+        # defined below. Don't ask. Just do it, Python! *sigh*
         self.hint = hint
 
     # ..................{ PROPERTIES                         }..................
@@ -237,9 +246,10 @@ class ViolationCause(object):
         # Sanitize this hint if unsupported by @beartype in its current form
         # (e.g., "numpy.typing.NDArray[...]") to another form supported by
         # @beartype (e.g., "typing.Annotated[numpy.ndarray, beartype.vale.*]").
-        hint = sanify_hint_child(
+        hint = sanify_hint_any(
             hint=hint,
             conf=self.conf,
+            arg_name=self.pith_name,
             exception_prefix=self.exception_prefix,
         )
 
@@ -317,6 +327,16 @@ class ViolationCause(object):
         # Getter function returning the desired string.
         cause_finder: Callable[[ViolationCause], ViolationCause] = None  # type: ignore[assignment]
 
+        #FIXME: Trivially simplify this method by:
+        #* Define a new find_cause_nonpep() function elsewhere whose body is
+        #  the body of this "if" conditional branch.
+        #* Register this function with PEP_HINT_SIGN_TO_GET_CAUSE_FUNC: e.g.,
+        #  PEP_HINT_SIGN_TO_GET_CAUSE_FUNC = {
+        #      ...,
+        #      None: find_cause_nonpep,
+        #  }
+        #* Remove this "if" conditional branch.
+
         # If *NO* sign uniquely identifies this hint, this hint is either
         # PEP-noncompliant *OR* only contextually PEP-compliant in certain
         # specific use cases. In either case...
