@@ -10,6 +10,7 @@ This private submodule is *not* intended for importation by downstream callers.
 '''
 
 # ....................{ IMPORTS                            }....................
+from beartype._data.datatyping import MappingKeysStr
 from beartype._util.cls.utilclstest import is_type_subclass
 from beartype._util.py.utilpyversion import IS_PYTHON_3_8
 
@@ -53,7 +54,7 @@ def is_hint_pep589(hint: object) -> bool:
        :func:`beartype._util.hint.pep.utilpepget.get_hint_pep_sign_or_none`
        getter, which internally calls this unmemoized tester.
     #. Compare the object returned by that getter against the
-       :attr:`from beartype._util.data.hint.pep.sign.datapepsigns.HintSignTypedDict`
+       :attr:`beartype._util.data.hint.pep.sign.datapepsigns.HintSignTypedDict`
        sign.
 
     Parameters
@@ -139,3 +140,40 @@ def is_hint_pep589(hint: object) -> bool:
             )
         )
     )
+
+# ....................{ REDUCERS                           }....................
+#FIXME: Remove *AFTER* deeply type-checking typed dictionaries. For now,
+#shallowly type-checking such hints by reduction to untyped dictionaries
+#remains the sanest temporary work-around.
+def reduce_hint_pep589(
+    hint: object, exception_prefix: str, *args, **kwargs) -> object:
+    '''
+    Reduce the passed :pep:`589`-compliant **typed dictionary** (i.e.,
+    :class:`typing.TypedDict` subclass) to a lower-level type hint currently
+    supported by :mod:`beartype`.
+
+    This reducer is intentionally *not* memoized (e.g., by the
+    :func:`callable_cached` decorator), as the implementation trivially reduces
+    to an efficient one-liner.
+
+    Parameters
+    ----------
+    hint : object
+        Typed dictionary to be reduced.
+    exception_prefix : str, optional
+        Human-readable label prefixing the representation of this object in the
+        exception message.
+
+    All remaining passed arguments are silently ignored.
+
+    Returns
+    ----------
+    object
+        Lower-level type hint currently supported by :mod:`beartype`.
+    '''
+
+    # Silently ignore all child type hints annotating this dictionary by
+    # reducing this hint to a "Mapping" type hint. Yes, "Mapping" rather than
+    # "dict". By PEP 589 edict:
+    #     First, any TypedDict type is consistent with Mapping[str, object].
+    return MappingKeysStr
