@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2022 Beartype authors.
+# Copyright (c) 2014-2023 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -26,12 +26,12 @@ def die_unless_typehint(obj: object) -> None:
 
     Raises
     ----------
-    BeartypeDoorException
+    beartype.roar.BeartypeDoorException
         If this object is *not* a type hint wrapper.
     '''
 
     # Avoid circular import dependencies.
-    from beartype.door._doorcls import TypeHint
+    from beartype.door._cls.doorsuper import TypeHint
 
     # If this object is *NOT* a type hint wrapper, raise an exception.
     if not isinstance(obj, TypeHint):
