@@ -17,20 +17,21 @@ concerns (e.g., PEP-compliance, PEP-noncompliance).
 # package-specific submodules at module scope.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
 
-# ....................{ TESTS ~ pass : wrappee : static    }....................
-def test_decor_wrappee_type_descriptor() -> None:
+# ....................{ TESTS ~ wrappee                    }....................
+def test_decor_wrappee_decorator_builtin() -> None:
     '''
-    Test successful usage of the :func:`beartype.beartype` decorator on all
-    **C-based unbound builtin method descriptors** (i.e., methods decorated by
-    builtin method decorators).
+    Test the :func:`beartype.beartype` decorator on **C-based unbound builtin
+    method descriptors** (i.e., methods decorated by builtin method decorators).
     '''
 
+    # ....................{ IMPORTS                        }....................
     # Defer test-specific imports.
     from beartype import beartype
     from beartype.roar import BeartypeCallHintParamViolation
     from beartype.typing import NoReturn
     from pytest import raises
 
+    # ....................{ CLASSES                        }....................
     class OrDidASeaOfFire(object):
         '''
         Arbitrary class declaring a class method, static method, property
@@ -139,10 +140,11 @@ def test_decor_wrappee_type_descriptor() -> None:
 
             raise ValueError('And their place is not known.')
 
-
+    # ....................{ LOCALS                         }....................
     # Instance of this class.
     the_race = OrDidASeaOfFire()
 
+    # ....................{ PASS                           }....................
     # Assert this class method accessed on both this instance and this class
     # returns the expected value.
     assert (
@@ -165,16 +167,14 @@ def test_decor_wrappee_type_descriptor() -> None:
     )
 
     # Assert this static method docstring has been preserved as is.
-    assert OrDidASeaOfFire.the_wilderness_has_a_mysterious_tongue.__doc__ is not None
-    assert OrDidASeaOfFire.the_wilderness_has_a_mysterious_tongue.__doc__.startswith('''
+    assert (
+        OrDidASeaOfFire.the_wilderness_has_a_mysterious_tongue.__doc__ is not
+        None
+    )
+    assert (
+        OrDidASeaOfFire.the_wilderness_has_a_mysterious_tongue.__doc__.startswith('''
             Arbitrary static method''')
-
-    # Assert this static method accessed on both this instance and this class
-    # when passed an invalid parameter raises the expected exception.
-    with raises(BeartypeCallHintParamViolation):
-        OrDidASeaOfFire.the_wilderness_has_a_mysterious_tongue(b'his work and dwelling')
-    with raises(BeartypeCallHintParamViolation):
-        the_race.the_wilderness_has_a_mysterious_tongue(b'his work and dwelling')
+    )
 
     # Assert this property getter method accessed on this instance returns the
     # expected value.
@@ -191,6 +191,21 @@ def test_decor_wrappee_type_descriptor() -> None:
     assert the_race.where_the_old_earthquake_daemon == (
         "Vanish, like smoke before the tempest's stream,")
 
+    # Assert this property method docstring has been preserved as is.
+    assert OrDidASeaOfFire.where_the_old_earthquake_daemon.__doc__ is not None
+    assert OrDidASeaOfFire.where_the_old_earthquake_daemon.__doc__.startswith('''
+            Arbitrary property getter method''')
+
+    # ....................{ FAIL                           }....................
+    # Assert this static method accessed on both this instance and this class
+    # when passed an invalid parameter raises the expected exception.
+    with raises(BeartypeCallHintParamViolation):
+        OrDidASeaOfFire.the_wilderness_has_a_mysterious_tongue(
+            b'his work and dwelling')
+    with raises(BeartypeCallHintParamViolation):
+        the_race.the_wilderness_has_a_mysterious_tongue(
+            b'The voiceless lightning in these solitudes')
+
     # Assert this property setter method accessed on this instance when passed
     # an invalid parameter raises the expected exception.
     with raises(BeartypeCallHintParamViolation):
@@ -198,7 +213,7 @@ def test_decor_wrappee_type_descriptor() -> None:
             b'And their place is not known. Below, vast caves')
 
     # Assert this property deleter method accessed on this instance raises the
-            # expected exception.
+    # expected exception.
     with raises(ValueError) as exception_info:
         del the_race.where_the_old_earthquake_daemon
 
@@ -208,10 +223,73 @@ def test_decor_wrappee_type_descriptor() -> None:
     # Assert this exception message is the expected string.
     assert exception_message == 'And their place is not known.'
 
-    # Assert this property method docstring has been preserved as is.
-    assert OrDidASeaOfFire.where_the_old_earthquake_daemon.__doc__ is not None
-    assert OrDidASeaOfFire.where_the_old_earthquake_daemon.__doc__.startswith('''
-            Arbitrary property getter method''')
+
+def test_decor_wrappee_callable_pseudo() -> None:
+    '''
+    Test the :func:`beartype.beartype` decorator on **pseudo-callables** (i.e.,
+    objects defining the pure-Python ``__call__()`` dunder method).
+    '''
+
+    # ....................{ IMPORTS                        }....................
+    # Defer test-specific imports.
+    from beartype import beartype
+    from beartype.roar import BeartypeCallHintParamViolation
+    from pytest import raises
+
+    # ....................{ CLASSES                        }....................
+    class WildWestWind(object):
+        '''
+        Arbitrary **pseudo-callable** (i.e., object defining the pure-Python
+        ``__call__()`` dunder method).
+        '''
+
+        def __call__(self, leaves_dead: str) -> str:
+            '''Arbitrary docstring.'''
+
+            return f'{leaves_dead}: O thou,'
+
+    # ....................{ LOCALS                         }....................
+    # Arbitrary pseudo-callables instance of this class.
+    autumns_being   = WildWestWind()
+    unseen_presence = WildWestWind()
+
+    # ....................{ PASS                           }....................
+    # Pseudo-callable wrapped with runtime type-checking.
+    autumns_being_typed = beartype(autumns_being)
+
+    # Assert that both the original and new pseudo-callables accept and return
+    # strings.
+    assert autumns_being(
+        "O wild West Wind, thou breath of Autumn's being,") == (
+        "O wild West Wind, thou breath of Autumn's being,: O thou,")
+    assert autumns_being_typed(
+        'Thou, from whose unseen presence the leaves dead') == (
+        'Thou, from whose unseen presence the leaves dead: O thou,')
+    assert unseen_presence(
+        'Pestilence-stricken multitudes: O thou,') == (
+        'Pestilence-stricken multitudes: O thou,: O thou,')
+
+    # ....................{ FAIL                           }....................
+    # Assert that both the original and new pseudo-callables raise the expected
+    # exception when passed invalid parameters.
+    #
+    # Note that the original pseudo-callable has been augmented with runtime
+    # type-checking despite *NOT* being passed to @beartype. Is this expected?
+    # Yes. Is this desirable? Maybe not. Either way, there's nothing @beartype
+    # can particularly do about it. Why? Because Python ignores the __call__()
+    # dunder method defined on objects; Python only respects the __call__()
+    # dunder method defined on the types of objects. Because of this, @beartype
+    # has *NO* recourse but to globally monkey-patch the type of the passed
+    # pseudo-callable (rather than that pseudo-callable itself).
+    with raises(BeartypeCallHintParamViolation):
+        autumns_being(
+            b'Are driven, like ghosts from an enchanter fleeing,')
+    with raises(BeartypeCallHintParamViolation):
+        autumns_being_typed(
+            b'Yellow, and black, and pale, and hectic red,')
+    with raises(BeartypeCallHintParamViolation):
+        unseen_presence(
+            b'Who chariotest to their dark wintry bed')
 
 # ....................{ TESTS ~ fail : arg                 }....................
 def test_decor_arg_name_fail() -> None:
